@@ -12,11 +12,11 @@ Passwd::Keyring::KDEWallet - Password storage implementation based on KDE Wallet
 
 =head1 VERSION
 
-Version 0.2001
+Version 0.2002
 
 =cut
 
-our $VERSION = '0.2001';
+our $VERSION = '0.2002';
 
 our $APP_NAME = "Passwd::Keyring";
 our $FOLDER_NAME = "Perl-Passwd-Keyring";
@@ -27,25 +27,44 @@ KDE Wallet based implementation of L<Passwd::Keyring>.
 
     use Passwd::Keyring::KDEWallet;
 
-    my $keyring = Passwd::Keyring::KDEWallet->new(app=>"My beautiful app", group=>"My app web passwords");
+    my $keyring = Passwd::Keyring::KDEWallet->new(
+         app=>"blahblah scraper",
+         group=>"Johnny web scrapers",
+    );
 
-    $keyring->set_password("John", "verysecret", "my-pseudodomain");
-    # And later, on next run maybe
-    my $password = $keyring->get_password("John", "my-pseudodomain");
-    # plus
-    $keyring->clear_password("John", "my-pseudodomain");
+    my $username = "John";  # or get from .ini, or from .argv...
 
-Note: see L<Passwd::Keyring::Auto::KeyringAPI> for detailed comments on
-keyring method semantics (this document is installed with
-Passwd::Keyring::Auto package).
+    my $password = $keyring->get_password($username, "blahblah.com");
+    unless( $password ) {
+        $password = <somehow interactively prompt for password>;
+
+        # securely save password for future use
+        $keyring->set_password($username, "blahblah.com");
+    }
+
+    login_somewhere_using($username, $password);
+    if( password_was_wrong ) {
+        $keyring->clear_password($username, "blahblah.com");
+    }
+
+Note: see L<Passwd::Keyring::Auto::KeyringAPI> for detailed comments
+on keyring method semantics (this document is installed with
+C<Passwd::Keyring::Auto> package).
 
 =head1 SUBROUTINES/METHODS
 
-=head2 new
+=head2 new(app=>'app name', group=>'passwords folder')
 
 Initializes the processing. Croaks if kwallet does not 
 seem to be available.
 
+Handled named parameters: 
+
+- app - symbolic application name (used in "Application .... is asking to open the wallet"
+  KDE Wallet prompt)
+
+- group - name for the password group (used as KDE Wallet folder name)
+
 =cut
 
 sub new {
@@ -181,7 +200,7 @@ L<https://bitbucket.org/Mekk/perl-keyring-kdewallet>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010-2012 Marcin Kasperski.
+Copyright 2012 Marcin Kasperski.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
